﻿using System;
using System.Drawing;

using Foundation;
using UIKit;
using Syncfusion.SfChart.iOS;
using CoreGraphics;
using CoreAnimation;
using System.Collections.ObjectModel;

namespace ChartSample
{

	public class ChartDelegate : SFChartDelegate
	{

		ChartDataModel datasource;

		public ChartDelegate(ChartDataModel dSource)
		{
			datasource = dSource;
		}

		public override void WillShowTooltip(SFChart chart, SFChartTooltip tooltipView)
		{
			UIView CustView	 = new UIView();
			CustView.Frame 	 = new CGRect(0,0,120,30);



			var tooltipindex = tooltipView.Series.ValueForKey(new NSString("tooltipDataPointIndex"));
			int index = ((NSNumber)tooltipindex).Int32Value;

			var seriesIndex = chart.IndexOfSeries(tooltipView.Series);

			UILabel xValue = new UILabel();
			xValue.Frame = new CGRect(0, 0, 30, 28);

			UILabel yValue = new UILabel();
			yValue.Frame = new CGRect(30, 0, 30, 28);

			UILabel thirdValue = new UILabel();
			thirdValue.Frame = new CGRect(60, 0, 30, 28);

			UILabel FourthValue = new UILabel();
			FourthValue.Frame = new CGRect(90, 0, 30, 28);

			if (seriesIndex == 0)
			{
				xValue.Text = datasource.DataPoints[index].XValue.ToString();
				yValue.Text = datasource.DataPoints[index].YValue.ToString();
				thirdValue.Text = datasource.DataPoints[index].Average.ToString();
				FourthValue.Text = datasource.DataPoints[index].CalculatedValues.ToString();
			}
			else
			{
				xValue.Text = datasource.DataPoints2[index].XValue.ToString();
				yValue.Text = datasource.DataPoints2[index].YValue.ToString();
				thirdValue.Text = datasource.DataPoints2[index].Average.ToString();
				FourthValue.Text = datasource.DataPoints2[index].CalculatedValues.ToString();
			}

				CustView.AddSubview(xValue);
				CustView.AddSubview(yValue);
				CustView.AddSubview(thirdValue);
				CustView.AddSubview(FourthValue);
				tooltipView.CustomView = CustView;
		}

	}

	public partial class ChartSampleViewController : UIViewController
	{

		public ChartSampleViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		#region View lifecycle
		SFChart chart;
		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			chart                         		= new SFChart ();
			chart.EdgeInsets 				  	= new UIEdgeInsets (25,10,10,20);
			chart.Frame                        	= this.View.Frame;


			chart.Title.Text 					= new NSString ("Chart Sample");

			SFCategoryAxis primaryAxis         	= new SFCategoryAxis ();
			primaryAxis.ShowMajorGridLines 		= false;
			chart.PrimaryAxis                   = primaryAxis;

			SFNumericalAxis secondaryAxis 	  	= new SFNumericalAxis ();
			secondaryAxis.ShowMajorGridLines	= false;
			secondaryAxis.ShowMinorGridLines	= false;
			secondaryAxis.Visible 				= false;
			chart.SecondaryAxis                	= secondaryAxis;
	
			ChartDataModel dataModel           	= new ChartDataModel ();
			chart.DataSource                   	= dataModel as SFChartDataSource;


			chart.Delegate = new ChartDelegate (dataModel);

		

			this.View.AddSubview (chart);

		}

		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
		}

		public override void ViewDidDisappear (bool animated)
		{

			base.ViewDidDisappear (animated);
		}

		#endregion
	}

	public class DataModel

	{
		public string XValue
		{
			get;
			set;
		}

		public double YValue
		{
			get;
			set;
		}

		public double Average
		{
			get;
			set;
		}
		public double CalculatedValues
		{
			get;
			set;
		}

		public DataModel(string x, double y, double ave, double cal )
		{
			this.XValue = x;
			this.YValue = y;
			this.Average = ave;
			this.CalculatedValues = cal;
		}

	}
		
	public class ChartDataModel : SFChartDataSource
	{
		public ObservableCollection<DataModel> DataPoints
		{
			get;
			set;
		}	

		public ObservableCollection<DataModel> DataPoints2
		{
			get;
			set;
		}

		public ChartDataModel ()
		{
			DataPoints = new ObservableCollection<DataModel> ();

			AddDataPointsForChart("01", 28,22,12);
			AddDataPointsForChart("02", 70,33,14);
			AddDataPointsForChart("03", 20,44,15);
			AddDataPointsForChart("04", 35,55,22);
			AddDataPointsForChart("05", 83,66,20);
			AddDataPointsForChart("06", 17,12,14);

			DataPoints2 = new ObservableCollection<DataModel>();
			AddDataPoints2ForChart("01", 48, 22,12);
			AddDataPoints2ForChart("02", 50, 32,14);
			AddDataPoints2ForChart("03", 10, 40,16);
			AddDataPoints2ForChart("04", 25, 51,18);
			AddDataPoints2ForChart("05", 63, 60,20);
			AddDataPoints2ForChart("06", 27, 42,22);

		}

		void AddDataPointsForChart (String month, Double value,Double average, Double calValues)
		{
			DataPoints.Add (new DataModel( month,value,average,calValues));

		}

		void AddDataPoints2ForChart(String month, Double value, Double average, Double calValues)
		{
			DataPoints2.Add(new DataModel(month, value, average, calValues));
		}

		public override nint NumberOfSeriesInChart (SFChart chart)
		{
			return 2; 
		}

		public override SFSeries GetSeries (SFChart chart, nint index)
		{
			if (index == 0)
			{
				SFStackingColumnSeries series = new SFStackingColumnSeries();
				series.EnableTooltip = true;
				return series;
			}
			else
			{
				SFStackingColumnSeries series = new SFStackingColumnSeries();
				series.EnableTooltip = true;
				return series;
			}

		}

		public override SFChartDataPoint GetDataPoint (SFChart chart, nint index, nint seriesIndex)
		{
			if (seriesIndex == 0)
			{
				return new SFChartDataPoint(NSObject.FromObject(DataPoints[(int)index].XValue),NSObject.FromObject(DataPoints[(int)index].YValue));
			}
			else
			{
				return new SFChartDataPoint(NSObject.FromObject(DataPoints2[(int)index].XValue), NSObject.FromObject(DataPoints2[(int)index].YValue));
			}
		}

		public override nint GetNumberOfDataPoints (SFChart chart, nint index)
		{
			if (index == 0)
			{
				return (int)DataPoints.Count;
			}
			else
			{
				return (int)DataPoints2.Count;
			}
		}
	}
}
